<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Nome_do_Programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>Usage</source>
        <translation>Utilização</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Dock Preview</source>
        <translation>Visualizar doca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Add New Application</source>
        <translation>Adicionar nova aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Add application</source>
        <translation>Adicionar aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>Delete this application</source>
        <translation>Eliminar esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Border</source>
        <translation>Contorno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="664"/>
        <source>Background</source>
        <translation>Fundo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Back</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>File</source>
        <translation>Ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <location filename="../mainwindow.cpp" line="861"/>
        <location filename="../mainwindow.cpp" line="979"/>
        <location filename="../mainwindow.cpp" line="1017"/>
        <location filename="../mainwindow.cpp" line="1042"/>
        <source>Select icon...</source>
        <translation>Seleccionar ícone...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <location filename="../mainwindow.cpp" line="102"/>
        <location filename="../mainwindow.cpp" line="800"/>
        <location filename="../mainwindow.cpp" line="865"/>
        <location filename="../mainwindow.cpp" line="982"/>
        <source>Select...</source>
        <translation>Seleccionar...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Move right</source>
        <translation>Mover para a direita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="146"/>
        <source>Move left</source>
        <translation>Mover para a esquerda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <location filename="../mainwindow.ui" line="338"/>
        <location filename="../mainwindow.ui" line="514"/>
        <location filename="../mainwindow.ui" line="579"/>
        <source>Click to select different color...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <source>Apply style to all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Hover Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>36x36</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>40x40</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Hover Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="716"/>
        <source>Display help </source>
        <translation>Mostrar ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="719"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="726"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="755"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="758"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="797"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="800"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="848"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <source>Alt+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="128"/>
        <source>1. Add applications to the dock one at a time
2. Select a .desktop file or enter a command for the application you want
3. Select icon attributes for size, background (black is standard) and border
4. Press &quot;Add application&quot; to continue or &quot;Save&quot; to finish</source>
        <translation>1. Adicionar aplicações à doca, uma a uma
2. Seleccionar um ficheiro .desktop ou introduzir um comando para a aplicação a adicionar
3. Seleccionar atributos de ícone para tamanho, fundo (preto predefinido) e margem
4. Premir &quot;Adicionar aplicação&quot; para continuar ou &quot;Guardar&quot; para terminar</translation>
    </message>
    <message>
        <source>black</source>
        <translation type="vanished">preto</translation>
    </message>
    <message>
        <source>white</source>
        <translation type="vanished">branco</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <source>This tool allows you to create a new dock with one or more applications. You can also edit or delete a dock created earlier.</source>
        <translation>Esta ferramenta possibilita a criação de novas docas com uma ou mais aplicações. Também possibilita editar ou eliminar uma doca existente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>Operation mode</source>
        <translation>Modo de operação</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>&amp;Move</source>
        <translation>&amp;Mover</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="172"/>
        <source>&amp;Delete</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="173"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="174"/>
        <source>C&amp;reate</source>
        <translation>C&amp;riar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>Dock name</source>
        <translation>Nome da doca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>Enter the name to show in the Menu:</source>
        <translation>Introduzir o nome a aparecer no Menu:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Select dock to delete</source>
        <translation>Seleccionar a doca a eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>Confirmation</source>
        <translation>Confirmação</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Eliminar realmente %1?</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="vanished">&amp;Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Seguinte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Select dock to move</source>
        <translation>Seleccionar a doca a mover</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <location filename="../mainwindow.cpp" line="426"/>
        <location filename="../mainwindow.cpp" line="641"/>
        <location filename="../mainwindow.cpp" line="926"/>
        <source>Dock Files (*.mxdk);;All Files (*.*)</source>
        <translation>Ficheiros de doca (*.imxdk);;Todos os ficheiros (*.*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>Error</source>
        <translation type="unfinished">Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>Failed to delete the selected dock.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <location filename="../mainwindow.cpp" line="461"/>
        <location filename="../mainwindow.cpp" line="937"/>
        <source>Could not open file</source>
        <translation>Não foi possível abrir o ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Overwrite?</source>
        <translation>Sobrescrever?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Do you want to overwrite the dock file?</source>
        <translation> Sobrescrever o ficheiro da doca?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="640"/>
        <source>Save file</source>
        <translation>Guardar ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="713"/>
        <source>Dock saved</source>
        <translation>Doca guardada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>The dock has been saved.

To edit the newly created dock please select &apos;Edit an existing dock&apos;.</source>
        <translation>A doca foi guardada.

Para a editar seleccionar &apos;Editar uma doca existente&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="732"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="732"/>
        <source>MX Dockmaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="733"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="734"/>
        <source>Description goes here</source>
        <translation>Inserir descrição aqui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="737"/>
        <source>Copyright (c) MX Linux</source>
        <translation> Direitos de autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="738"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="747"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="904"/>
        <source>Select .desktop file</source>
        <translation>Seleccionar o ficheiro .desktop</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="905"/>
        <source>Desktop Files (*.desktop)</source>
        <translation>Ficheiros de Ambiente Trab (*.desktop)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="925"/>
        <source>Select a dock file</source>
        <translation>Seleccionar um ficheiro de doca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="930"/>
        <source>No file selected</source>
        <translation>Nenhum ficheiro seleccionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="931"/>
        <source>You haven&apos;t selected any dock file to edit.
Creating a new dock instead.</source>
        <translation>Não foi seleccionado nenhum ficheiro de doca para editar.
A criar uma nova doca em vez disso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="938"/>
        <source>Could not open selected file.
Creating a new dock instead.</source>
        <translation>Não foi possível abrir o ficheiro seleccionado.
A criar uma nova doca em vez disso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="946"/>
        <source>1. Edit applications one at a time using the Back and Next buttons
2. Add or delete applications as you like
3. When finished click Save</source>
        <translation>1. Editar as aplicações uma a uma usando os botões &apos;Anterior&apos; e &apos;Seguinte&apos;
2. Adicionar ou eliminar aplicações como pretendido
3. Quando terminado clicar em &apos;Guardar&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1023"/>
        <source>Select icon</source>
        <translation>Seleccionar ícone</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1024"/>
        <source>Icons (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation>Ícones (*.png *.jpg *.bmp *.xpm *.svg)</translation>
    </message>
</context>
<context>
    <name>PickLocation</name>
    <message>
        <location filename="../picklocation.ui" line="14"/>
        <source>Dialog</source>
        <translation>Caixa de diálogo</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="23"/>
        <source>Dock Location</source>
        <translation>Localização da doca</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="29"/>
        <source>TopCenter</source>
        <translation>CimoCentro</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="45"/>
        <source>BottomLeft</source>
        <translation>FundoEsquerda</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="61"/>
        <source>BottomCenter</source>
        <translation>FundoCentro</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="80"/>
        <source>TopLeft</source>
        <translation>CimoEsquerda</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="96"/>
        <source>TopRight</source>
        <translation>CimoDireita</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="112"/>
        <source>LeftCenter</source>
        <translation>EsquerdaCentro</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="128"/>
        <source>RightCenter</source>
        <translation>DireitaCentro</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="144"/>
        <source>BottomRight</source>
        <translation>FundoDireita</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="160"/>
        <source>RightTop</source>
        <translation>DireitaCimo</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="173"/>
        <source>LeftTop</source>
        <translation>EsquerdaCimo</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="189"/>
        <source>LeftBottom</source>
        <translation>EsquerdaFundo</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="205"/>
        <source>RightBottom</source>
        <translation>DireitaFundo</translation>
    </message>
    <message>
        <location filename="../picklocation.cpp" line="9"/>
        <source>Select dock location</source>
        <translation>Seleccionar a localização da doca</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>License</source>
        <translation type="vanished">Licença</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Registo de alterações</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Fechar</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Erro</translation>
    </message>
    <message>
        <source>You must run this program as normal user.</source>
        <translation type="vanished">Este programa tem que executado como utilizador normal.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation type="unfinished">Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished">Registo de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <location filename="../main.cpp" line="75"/>
        <source>Error</source>
        <translation type="unfinished">Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You must run this program as normal user.</source>
        <translation type="unfinished">Este programa tem que executado como utilizador normal.</translation>
    </message>
</context>
</TS>
